@@ -8,7 +8,7 @@ use File::stat;
 use Term::ProgressBar;
 
 # ABSTRACT: Perl Interface to the Gameboy Advance
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Carp;
 
@@ -22,7 +22,7 @@ Device::GBA - Perl Interface to the Gameboy Advance
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ sub enter_spi
 
    $self->{spi} = $self->{adapter}->make_protocol("SPI")->get;
    $self->{spi}->configure(mode => 3, max_bitrate => $self->{bitrate},
-      opendrain => 0)->get;
+      open_drain => 0)->get;
 }
 
 =item upload
